@@ -343,7 +343,7 @@ class ServiceInterface:
     :vartype name: str
     """
 
-    def __init__(self, name: str):
+    def __init__(self, name: str) -> None:
         # TODO cannot be overridden by a dbus member
         self.name = name
         self.__methods: List[_Method] = []
@@ -490,9 +490,7 @@ class ServiceInterface:
 
     @staticmethod
     def _msg_body_to_args(msg: Message) -> List[Any]:
-        if not msg.unix_fds or not signature_contains_type(
-            msg.signature_tree, msg.body, "h"
-        ):
+        if not signature_contains_type(msg.signature_tree, msg.body, "h"):
             return msg.body
 
         # XXX: This deep copy could be expensive if messages are very
